package com.shcd.boat.sms;

import cn.hutool.core.codec.Base64;
import cn.hutool.crypto.SecureUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson2.JSON;
import com.shcd.boat.entity.sms.MASNorSubmit;
import com.shcd.boat.entity.sms.MASSMSResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;

@Slf4j
@Component
public class MASSMSService {
    //企业名称
    private final String ecName = "上海市浦东新区航务事业发展中心";
    //接口账号用户名
    @Value("${SMS.apId}")
    private String apId;
    //接口账号用密码
    @Value("${SMS.secretKey}")
    private String secretKey;
    //签名编码    在云MAS平台『管理』→『接口管理』→『短信接入用户管理』获取。
    @Value("${SMS.sign}")
    private String sign;

    @Value("${SMS-URL}")
    private String url;

    //发送普通短信
    public boolean commonSend(String mobiles, String content){
        MASNorSubmit masNorSubmit = this.getMASNorSubmit(mobiles, content);
        String submitJson = JSON.toJSONString(masNorSubmit);
        log.info("submitJson:" + submitJson);
        String encode = Base64.encode(submitJson.getBytes(StandardCharsets.UTF_8));
        log.info("encode:" + encode);
        String responseStr = HttpUtil.post(url, encode);
        log.info("短信发送结果Response:" + responseStr);
        MASSMSResponse response = JSON.parseObject(responseStr, MASSMSResponse.class);
        log.info("短信发送结果Response:" + response.toString());
        if(!response.isSuccess()) {
            log.warn("短信发送失败");
            return false;
        }else {
            return true;
        }
    }

    //获取短信发送请求体
    private MASNorSubmit getMASNorSubmit(String mobiles, String content){
        MASNorSubmit masNorSubmit = new MASNorSubmit();
        masNorSubmit.setEcName(ecName);
        masNorSubmit.setApId(apId);
        masNorSubmit.setSecretKey(secretKey);
        masNorSubmit.setMobiles(mobiles);
        masNorSubmit.setContent(content);
        masNorSubmit.setSign(sign);
        masNorSubmit.setAddSerial("");
        masNorSubmit.setMac(this.getMac(masNorSubmit));
        return masNorSubmit;
    }

    //获取请求体MAC字符
    private String getMac(MASNorSubmit masNorSubmit){
        String preStr = masNorSubmit.getEcName() +
                masNorSubmit.getApId() +
                masNorSubmit.getSecretKey() +
                masNorSubmit.getMobiles() +
                masNorSubmit.getContent() +
                masNorSubmit.getSign() +
                masNorSubmit.getAddSerial();
        String selfMac = SecureUtil.md5(preStr);
        System.out.println("selfMac:" + selfMac);
        return selfMac;
    }
}
