package com.shcd.boat.utils;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.shcd.boat.entity.ShipInfoResponse;
import com.shcd.boat.entity.gh.GHAisInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

@Slf4j
public class GhjgRpcUtils {


    /**
     * 获取市港航token
     * @param url
     * @return
     */
    public  static  String getGhThreeDataShareToken(String url) {
        String DATA_SHARE_TOKEN_URL  =url+"/auth/getToken";
        Map<String, Object> params = new HashMap<>();
        params.put("key", "PNSmD0Te");
        params.put("secret", "0d254e70110e1164b3f5a1167d15b092adbc9634");
        String json = com.alibaba.fastjson2.JSON.toJSONString(params);
        /*HttpRequest post = HttpUtil.createPost(url);
        post.body(json);*/
        String response = HttpUtil.post(DATA_SHARE_TOKEN_URL, json);
        log.info("getGhThreeDataShareTokenn获取token，请求结果：" + response);
        if(StrUtil.isBlank(response)){
            return null;
        }
        com.alibaba.fastjson2.JSONObject jsonObject = com.alibaba.fastjson2.JSON.parseObject(response);
        //Integer code = (Integer) jsonObject.get("code");
        String token = (String) jsonObject.get("msg");
        return token;
    }

    /**
     * 获取AIS数据
     * @param url
     * @param reqParams
     * @return
     */
    public static   String getAISData(String url,JSONObject reqParams) {
        String DOC_NUMBER_URL = url+"/boat/getAisRealTimeXY";
        String k = "ghThreeDataShare";
        String json2 =  reqParams.toJSONString();
        log.info("---    请求入参内容data："+json2);
        String encJson2 = GhEncodes.encodeBase64(Encodes.aesEncrypt(json2.getBytes(
                StandardCharsets.UTF_8),
                k.getBytes(),
                k.getBytes()));
        Map<String, Object> params = new HashMap<>();
        params.put("key", "PNSmD0Te");
        params.put("data", encJson2);
        String json = JSON.toJSONString(params);
        log.info("---    请求入参加密内容："+json);
        HttpRequest post = HttpUtil.createPost(DOC_NUMBER_URL);
        post.body(json);
        post.header("Authorization",getGhThreeDataShareToken(url));
        String response= post.execute().body();
        if (StringUtils.isNotBlank(response)) {
            log.info("---   返回消息体result:"+response);
            JSONObject jsonObject = JSON.parseObject(response);
            String encData = (String) jsonObject.get("data");
            String decData = new String(Encodes.aesDecrypt(
                    Encodes.decodeBase64(encData), k.getBytes(),
                    k.getBytes()), StandardCharsets.UTF_8);
            return  decData;
        }

        return null;
    }


    /**
     * 获取船舶基本信息
     * @param url
     * @param request
     * @return
     */
    public static ShipInfoResponse getShipInfo(String url,JSONObject request) {
        String GH_SHIPINFO_URL = url+"/boat/getInfoListPd";
        String k = "ghThreeDataShare";
        Map<String, Object> params = new HashMap<>();
        params.put("key", "PNSmD0Te");
        String json2 =  request.toJSONString();
        log.info("---    请求入参内容data："+json2);
        String encJson2 = GhEncodes.encodeBase64(Encodes.aesEncrypt(json2.getBytes(
                StandardCharsets.UTF_8),
                k.getBytes(),
                k.getBytes()));
        params.put("data", encJson2);
        String json = com.alibaba.fastjson2.JSON.toJSONString(params);
        log.info("---    请求入参加密内容："+json);
        HttpRequest post = HttpUtil.createPost(GH_SHIPINFO_URL);
        post.header("Authorization",getGhThreeDataShareToken(url));
        post.body(json);
        String response = post.execute().body();
        log.info("---   返回消息体result:"+response);
        com.alibaba.fastjson2.JSONObject jsonObject = com.alibaba.fastjson2.JSON.parseObject(response);
        if (200 != (int) jsonObject.get("code")){
            log.info("无返回数据:{}",jsonObject.get("msg").toString());
            return null;
        }
        String data = jsonObject.get("data").toString();
        String decData = new String(Encodes.aesDecrypt(
                Encodes.decodeBase64(data), k.getBytes(),
                k.getBytes()), StandardCharsets.UTF_8);
        return JSON.parseObject(decData, ShipInfoResponse.class);
    }

    /**
     * 获取船舶联系方式
     * @param url
     * @param request
     * @return
     */
    public static String getShipLianxi(String url,JSONObject request) {
        String GH_SHIPINFO_URL = url+"/boat/getBoatContactByMmsi";
        String k = "ghThreeDataShare";
        Map<String, Object> params = new HashMap<>();
        params.put("key", "PNSmD0Te");
        String json2 =  request.toJSONString();
        log.info("---    获取船舶联系方式请求入参内容data："+json2);
        String encJson2 = GhEncodes.encodeBase64(Encodes.aesEncrypt(json2.getBytes(
                StandardCharsets.UTF_8),
                k.getBytes(),
                k.getBytes()));
        params.put("data", encJson2);
        String json = com.alibaba.fastjson2.JSON.toJSONString(params);
        log.info("---    获取船舶联系方式请求入参加密内容："+json);
        HttpRequest post = HttpUtil.createPost(GH_SHIPINFO_URL);
        post.header("Authorization",getGhThreeDataShareToken(url));
        post.body(json);
        String response = post.execute().body();
        log.info("---   获取船舶联系方式返回消息体result:"+response);
         JSONObject jsonObject = JSON.parseObject(response);
        if (200 != (int) jsonObject.get("code")){
            log.info("---   无返回数据:{}",jsonObject.get("msg").toString());
            return null;
        }
        String data = jsonObject.get("data").toString();
        String decData = new String(Encodes.aesDecrypt(
                Encodes.decodeBase64(data), k.getBytes(),
                k.getBytes()), StandardCharsets.UTF_8);
        return decData;
    }




    /**
     * 获取船舶包港信息
     * @param url
     * @param request
     * @return
     */
    public static String getShipReportData(String url,JSONObject request) {
        String GH_SHIPINFO_URL = url+"/boat/getReportInfoList";
        String k = "ghThreeDataShare";
        Map<String, Object> params = new HashMap<>();
        params.put("key", "PNSmD0Te");
        String json2 =  request.toJSONString();
        log.info("---    获取船舶报港信息请求入参内容data："+json2);
        String encJson2 = GhEncodes.encodeBase64(Encodes.aesEncrypt(json2.getBytes(
                StandardCharsets.UTF_8),
                k.getBytes(),
                k.getBytes()));
        params.put("data", encJson2);
        String json = com.alibaba.fastjson2.JSON.toJSONString(params);
        log.info("---    获取船舶报港信息请求入参加密内容："+json);
        HttpRequest post = HttpUtil.createPost(GH_SHIPINFO_URL);
        post.header("Authorization",getGhThreeDataShareToken(url));
        post.body(json);
        String response = post.execute().body();
        log.info("---   获取船舶报港信息返回消息体result:"+response);
        JSONObject jsonObject = JSON.parseObject(response);
        if (200 != (int) jsonObject.get("code")){
            log.info("---   无返回数据:{}",jsonObject.get("msg").toString());
            return null;
        }
        String data = jsonObject.get("data").toString();
        String decData = new String(Encodes.aesDecrypt(
                Encodes.decodeBase64(data), k.getBytes(),
                k.getBytes()), StandardCharsets.UTF_8);
        return decData;
    }


    public static void main(String[] args) {
        String k = "ghThreeDataShare";

        String json2 ="{\"pageIndex\":1,\"pageSize\":10,\"district\":\"浦东新区\"," +
                "\"dateTo\":\"2025-01-22\",\"dateFrom\":\"2025-01-22\"," +
                "\"shipId\":\"CN20187649340\"}";
       JSONObject jsonObject=JSON.parseObject(json2);
        String result= getShipReportData("http://192.168.20.61:8001/ghThreeDataShare",jsonObject);
        System.out.println(result);
    }

    public static String getShipRecords(String transUrl, JSONObject request) {
        String SHIP_RECORDS_URL = transUrl+"/shorePower/getConnRecordInfoListSync";
        String k = "ghThreeDataShare";
        Map<String, Object> params = new HashMap<>();
        params.put("key", "PNSmD0Te");
        String json2 = JSON.toJSONString(request);
        String encJson2 = GhEncodes.encodeBase64(Encodes.aesEncrypt(json2.getBytes(
                        StandardCharsets.UTF_8),
                k.getBytes(),
                k.getBytes()));
        System.out.println(encJson2);
        params.put("data", encJson2);
        String json = com.alibaba.fastjson2.JSON.toJSONString(params);
        HttpRequest post = HttpUtil.createPost(SHIP_RECORDS_URL);
        post.body(json);
        post.header("Authorization",getGhThreeDataShareToken(transUrl));
        String response = post.execute().body();
        log.info("获取连船记录信息，请求结果：" + response);
        JSONObject jsonObject = JSON.parseObject(response);
        String encData = (String) jsonObject.get("data");
        String decData = new String(Encodes.aesDecrypt(
                Encodes.decodeBase64(encData), k.getBytes(),
                k.getBytes()), StandardCharsets.UTF_8);
        return decData;
    }
}
